==> 1.0.104+1.tar.gz: lib/components/UikPagination.dart <==
import 'package:ui_sdk/components/UikWidget.dart';
import 'package:ui_sdk/components/WidgetType.dart';
import '../props/UikPaginationProps.dart';
import 'package:flutter/material.dart';

class UikPagination extends UikWidget {
  WidgetType _widgetType;
  UikPaginationProps _UikPaginationProps;
  UikPagination(this._widgetType, this._UikPaginationProps)
      : super(_widgetType, _UikPaginationProps);

  @override
  _UikPaginationState createState() => _UikPaginationState(_UikPaginationProps);
}

class _UikPaginationState extends State<UikPagination> {
  UikPaginationProps _UikPaginationProps;
  _UikPaginationState(this._UikPaginationProps);

  List<Widget> indicators(imagesLength, currentIndex) {
    return List<Widget>.generate(imagesLength, (index) {
      return Container(
        color: Colors.white,
        child: Container(
          margin: const EdgeInsets.all(3),
          width: 10,
          height: 10,
          decoration: BoxDecoration(
              color: currentIndex == index ? Colors.black : Colors.black26,
              shape: BoxShape.circle),
        ),
      );
    });
  }

  int activePage = 0;
  @override
  Widget build(BuildContext context) {
    return Stack(children: [
      Column(
        children: [
          SizedBox(
            height: MediaQuery.of(context).size.height * 0.25,
            width: MediaQuery.of(context).size.width,
            child: PageView.builder(
                allowImplicitScrolling: true,
                scrollDirection: Axis.horizontal,
                pageSnapping: true,
                itemCount: _UikPaginationProps.imgList.length,
                itemBuilder: (context, pagePosition) {
                  return FittedBox(
                    child: Container(
                        child: _UikPaginationProps.imgList[pagePosition]),
                  );
                },
                onPageChanged: (page) {
                  setState(() {
                    activePage = page;
                  });
                }),
          ),
        ],
      ),
      Positioned(
        top: 200.0,
        left: MediaQuery.of(context).size.width / 2 - 30,
        child: ClipRRect(
          borderRadius: BorderRadius.circular(30.0),
          child: Row(
              mainAxisAlignment: MainAxisAlignment.center,
              children:
                  indicators(_UikPaginationProps.imgList.length, activePage)),
        ),
      ),
      Padding(
        padding: const EdgeInsets.all(15.0),
        child: _UikPaginationProps.hasIcons
            ? Row(
                mainAxisAlignment: MainAxisAlignment.spaceAround,
                children: [
                  _UikPaginationProps.iconList[0],
                  const SizedBox(width: 200),
                  _UikPaginationProps.iconList[1],
                  _UikPaginationProps.iconList[2]
                ],
              )
            : const SizedBox(),
      )
    ]);
  }
}

==> 1.0.111+1.tar.gz: lib/components/UikPagination.dart <==
import 'package:ui_sdk/components/UikWidget.dart';
import 'package:ui_sdk/components/WidgetType.dart';
import '../props/UikPaginationProps.dart';
import 'package:flutter/material.dart';

class UikPagination extends UikWidget {
  WidgetType _widgetType;
  UikPaginationProps _UikPaginationProps;
  UikPagination(this._widgetType, this._UikPaginationProps)
      : super(_widgetType, _UikPaginationProps);

  @override
  _UikPaginationState createState() => _UikPaginationState(_UikPaginationProps);
}

class _UikPaginationState extends State<UikPagination> {
  UikPaginationProps _UikPaginationProps;
  _UikPaginationState(this._UikPaginationProps);

  List<Widget> indicators(imagesLength, currentIndex) {
    return List<Widget>.generate(imagesLength, (index) {
      return Container(
        color: Colors.white,
        child: Container(
          margin: const EdgeInsets.all(3),
          width: 10,
          height: 10,
          decoration: BoxDecoration(
              color: currentIndex == index ? Colors.black : Colors.black26,
              shape: BoxShape.circle),
        ),
      );
    });
  }

  int activePage = 0;
  @override
  Widget build(BuildContext context) {
    return Stack(children: [
      Column(
        children: [
          Container(
            // color: Colors.red,
            height: MediaQuery.of(context).size.width - 32,
            width: MediaQuery.of(context).size.width - 32,
            margin: EdgeInsets.only(
                left: _UikPaginationProps.imageLeftMargin,
                right: _UikPaginationProps.imageRightMargin,
                top: _UikPaginationProps.imageTopMargin,
                bottom: _UikPaginationProps.imageBottomMargin),
            child: PageView.builder(
                allowImplicitScrolling: true,
                scrollDirection: Axis.horizontal,
                pageSnapping: true,
                itemCount: _UikPaginationProps.imgList.length,
                itemBuilder: (context, pagePosition) {
                  return Padding(
                    padding: EdgeInsets.all(_UikPaginationProps.imagePadding),
                    child: FittedBox(
                      fit: BoxFit.fill,
                      child: Container(
                          child: _UikPaginationProps.imgList[pagePosition]),
                    ),
                  );
                },
                onPageChanged: (page) {
                  setState(() {
                    activePage = page;
                  });
                }),
          ),
        ],
      ),
    _UikPaginationProps.imgList.length >1? Positioned(
      top: MediaQuery.of(context).size.width * 0.87,
      left: MediaQuery.of(context).size.width / 2 - 30,
      child: ClipRRect(
        borderRadius: BorderRadius.circular(30.0),
        child: Row(
            mainAxisAlignment: MainAxisAlignment.center,
            children:
            indicators(_UikPaginationProps.imgList.length, activePage)),
      ),
    ): SizedBox() ,
      Padding(
        padding: const EdgeInsets.all(15.0),
        child: _UikPaginationProps.hasIcons
            ? Row(
                mainAxisAlignment: MainAxisAlignment.spaceAround,
                children: [
                  _UikPaginationProps.iconList[0],
                  const SizedBox(width: 200),
                  _UikPaginationProps.iconList[1],
                  _UikPaginationProps.iconList[2]
                ],
              )
            : const SizedBox(),
      )
    ]);
  }
}
